pkgdown/extra.css

Skip to contents

[Experimental] This function runs annotation and data cleaning functions on a TIRTLseqDataSet object. Specifically, it calls the functions add_single_chain_data(), identify_paired(), identify_non_functional_seqs(), and (optionally) clean_pairs().

Usage

TIRTL_process(data, clean = FALSE, remove_nonfunctional = FALSE)

Arguments

data

a TIRTLseqDataSet object

clean

(optional) a TRUE/FALSE value, whether or not to "clean" the paired data by removing excess pairs for individual alpha and beta chains (default is FALSE).

remove_nonfunctional

whether to remove non-functional TCR chains (default is FALSE)

Value

a TIRTLseqDataSet object with annotated and (optionally) cleaned data