Add single-chain read counts/fractions to the paired TCR data
add_single_chain_data.Rd
The
add_single_chain_data() function adds read counts and proportions
from the single-chain pseudobulk data to the paired data frame for each sample
of a dataset.
Arguments
- data
a TIRTLseq dataset created by
load_tirtlseq()- verbose
(optional) whether to print progress of the function (default is TRUE).
Value
A TIRTLseq dataset object where the paired data frames for each sample have added columns for read counts and proportions from the single-chain pseudobulk data.
See also
Other data_processing:
TIRTL_process(),
clean_pairs(),
combine_bulk_and_paired_data(),
filter_duplicate_tcrs(),
filter_mait(),
filter_nonfunctional_TCRs(),
filter_short_cdr3s(),
filter_v_alleles(),
identify_non_functional_seqs(),
identify_paired(),
make_tcr_schema(),
prep_for_tcrdist(),
read_external_bulk(),
read_external_paired(),
remove_duplicates()