pkgdown/extra.css

Skip to contents

[Experimental] By default, the TIRTLseq pairing scripts write a "paired" data table that has one row per pair per pairing algorithm (MAD-HYPE or T-SHELL). Thus, any pairs identified by both methods will be found in two rows. This function removes those duplicates.

Usage

filter_duplicate_tcrs(df, verbose = TRUE)

Arguments

df

data frame with paired TCRs

verbose

whether to print number of TCRs removed