pkgdown/extra.css

Skip to contents

[Experimental] This function uses a heuristic to remove TCRs associated with MAIT cells, which may not be desired for some applications. For example, when creating a network of related TCRs with TCRdist, these TCRs often form a very highly dense sub-network that inflates output file size.

Usage

filter_mait(df, verbose = TRUE)

Arguments

df

data frame with paired TCRs

verbose

whether to print number of MAIT TCRs removed

Value

A data frame with MAIT TCRs removed

Details

We use a heiristic where we remove TCRs with V-alpha TRAV1-2 and either J-alpha segment TRAJ33, TRAJ12, or TRAJ20 (see Garner et al. 2023 - https://www.nature.com/articles/s41590-023-01575-1).