pkgdown/extra.css

Skip to contents

[Experimental] identify_non_functional_seqs() identifies CDR3 nucleotide sequences in the data that contain either stop codons (*) or frame shifts (_) that would indicate a non-functional protein product.

Usage

identify_non_functional_seqs(data)

Arguments

data

a TIRTLseqDataSet object

Value

A TIRTLseqDataSet object with modified pseudobulk and paired data frames for each sample. Each dataframe in the ouptut object has added columns that identify whether the CDR3 alpha and beta nucleotide sequences contain any stop codons (*) or frame shifts (_) that would indicate a non-functional chain.

Column is_functional is TRUE if neither chain has a stop codon or a frame shift. The columns has_stop_codon and has_frameshift are similar, but specific to each kind of coding error. Other columns identify if the alpha chain or beta chain has a stop codon or frameshift, and if it is functional.

Examples

# example code