Identify which single chains were paired
identify_paired.Rd
For each sample in the dataset,
identify_paired() annotates the alpha
and beta pseudobulk data with the number of distinct pairs each chain is a part of
in the paired data as well as a TRUE/FALSE column indicating whether the chain
is paired with any partners.
Arguments
- data
a TIRTLseq dataset created by
load_tirtlseq()- verbose
(optional) whether to print progress of the function (default is TRUE).
- by_method
(optional) whether to get stats for each pairing method
Value
A dataset similar to that created by load_tirtlseq(), but
with added columns is_paired and n_paired in the alpha and beta
pseudobulk data frames.
is_paired is TRUE if the chain is found in the
paired data. n_paired is the number of distinct chains that the particular
chain is paired with.
See also
Other data_processing:
TIRTL_process(),
add_single_chain_data(),
clean_pairs(),
combine_bulk_and_paired_data(),
filter_duplicate_tcrs(),
filter_mait(),
filter_nonfunctional_TCRs(),
filter_short_cdr3s(),
filter_v_alleles(),
identify_non_functional_seqs(),
make_tcr_schema(),
prep_for_tcrdist(),
read_external_bulk(),
read_external_paired(),
remove_duplicates()