pkgdown/extra.css Skip to contents

[Experimental] This is a convenience function that simply returns a vector of column names that are used by read_external_paired() to define a unique T-Cell receptor.

For example, using features = c("v", "cdr3_aa") will group all chains with the same V-alpha/beta and CDR3-alpha/beta amino acid sequence together, while using features = c("v", "cdr3_aa", "cdr3_nt") will require that their nucleotide sequence is also matching.

Usage

make_tcr_schema(
  features = c("v", "j", "cdr3_aa", "cdr3_nt"),
  second_alpha = FALSE
)

Arguments

features

some subset of c("v", "j", "cdr3_aa", "cdr3_nt") that you would like to use to define a unique receptor.

second_alpha

whether to include a second alpha chain (default is FALSE)

Value

A vector containing

Examples

make_tcr_schema() ## default: v, j, and cdr3 amino acid and nucleotide sequence
#> [1] "va"        "ja"        "cdr3a"     "cdr3b"     "vb"        "jb"       
#> [7] "alpha_nuc" "beta_nuc" 
make_tcr_schema(c("v", "j")) ## only v and j segments
#> [1] "va" "ja" "vb" "jb"