Removes duplicate paired TCRs
remove_duplicates.Rd
By default, paired TCRs are listed in one row in the paired chain data
for each pairing algorithm they were called by (either T-SHELL or MAD-HYPE). This means
some TCRs are present in two rows, once for each algorithm. This
function removes duplicate TCRs and returns a data frame where each TCR pair is
found in only one row.
Value
Returns a data frame (or list of data frames, depending on input) of paired TCRs where each TCR is listed only once.
See also
Other data_processing:
TIRTL_process(),
add_single_chain_data(),
clean_pairs(),
combine_bulk_and_paired_data(),
filter_duplicate_tcrs(),
filter_mait(),
filter_nonfunctional_TCRs(),
filter_short_cdr3s(),
filter_v_alleles(),
identify_non_functional_seqs(),
identify_paired(),
make_tcr_schema(),
prep_for_tcrdist(),
read_external_bulk(),
read_external_paired()