Add metadata to a TIRTLseqDataSet object
add_metadata.Rd
This function adds a metadata data frame,
obj$meta, to the input TIRTLseqDataSet object based on
the sample names. This can be useful when the metadata was not specified when the initial object was loaded.
Arguments
- obj
a TIRTLseqDataSet object
- meta_columns
(optional) a vector of names for metadata for each field in the sample names.
- sep
(optional) the character separating fields in the sample names of the data For example
c("marker", "timepoint", "donor")for samples named something like "cd8_timepoint2_donor1".
See also
Other data_wrangling:
filter_dataset(),
reorder_samples()