Choose a partner manually for an input chain using T-SHELL
choose_pair_manual.RdThis function takes in an object created by plot_tshell() and allows
a user to choose the partner for the input chain used to create that object.
Arguments
- res
an object created by
plot_tshell()- rank
the rank of the potential partner chain to choose
Value
A one-row data frame in the style of the "paired" data frame from pairing output with the input chain and its chosen partner.