Value
A vector of all available diversity metrics for the calculate_diversity() function.
See also
Other diversity:
calculate_diversity(),
plot_clonotype_indices(),
plot_diversity()
pkgdown/extra.css
Skip to contentsA vector of all available diversity metrics for the calculate_diversity() function.
Other diversity:
calculate_diversity(),
plot_clonotype_indices(),
plot_diversity()